CLI
---

The command line interface allows for running and visualising Pigreads
simulations from YAML or JSON files following the schema in
:py:class:`pigreads.schema.simulation.Simulation`.

.. automodule:: pigreads.cli

.. click:: pigreads.cli:main
    :prog: pigreads
    :nested: full
